static char RcsId[] = "$Header: error.c,v 1.5 94/01/11 21:27:33 will Exp $";
#include <stdio.h>
#include <errno.h>
#include <string.h>
#include <time.h>
#include <pwd.h>
#include <unistd.h>
#ifdef __STDC__
#include <stdarg.h>
#else
#include <varargs.h>
#endif

char *error_prog = NULL;

/* Error -- print error message, then optionally die.

 * Usage:	Error(show_perror, die, format, args... );
 *	Print error message according to format & args.
 *	If show_perror != 0 && errno != 0, follow error message with perror("").
 *	(If show_perror !=0, but errno==0, follow error msg with "\n").
 *	If die != 0, exit with exit(die).

 * If error_prog != NULL, then the message to stderr is preceded
 *	with "<error_prog>: ".

 * Return code is -1, so you can print error messages and return an error
 *	code with   return Error(...);
 */

/* VARARGS3 */
int
Error(
    int show_perror,	/* If errno != 0, follow msg with perror("") */
    int die,		/* If !0, exit with exit(die) */
    char *fmt,		/* Print rest of args with fprintf(stderr, fmt, ...) */
    ... )
{
    va_list ap;
    int error = errno;

    /* Program name */
    if (error_prog)
	(void) fprintf(stderr, "%s: ", error_prog);

    /* User's msg */
    va_start(ap, fmt);
    (void) vfprintf(stderr, fmt, ap);
    va_end(ap);

    if (show_perror) {
	if (error) {
	    errno = error;
	    perror("");
	} else {
	    (void) fputc('\n', stderr);
	}
    }

    if (die)
	(void) exit(die);

    return -1;

}
